==> GeneLab_Microarray-0.2-py2-none-any.whl: GeneLab-Microarray/batch_process.py <==
__author__ = 'Jonathan Rubin'

import os, config, metadata_process, rawdata_process


#This script is where the majority of the batch processing code resides. It's meant to loop through a batch.txt file and perform
#the necessary processing steps based on what's in the batch file.
def run(batch_file):
    #First, the batch.txt file is parsed and input into a batch_list variable
    batch_list = list()
    with open(batch_file) as F:
        parent_dir = F.readline().strip('\n').split('=')[1]
        header = F.readline()
        for line in F:
            linelist = line.strip('\n').split()
            if len(linelist) != 3:
                print "Error, batch file line not formatted properly: " + line + " skipping..."
            else:
                batch_list.append(linelist)

    #Once we have a batch_list variable fully populated, we loop through it and detect any 'False' booleans and perform necessary processing steps
    for i in range(len(batch_list)):
        if 'False' in batch_list[i]:
            GLDS, copy, norm_qc = batch_list[i]

            #Copy module, copies and unzips both metadata and raw data. If precise directories are not found,
            #that GLDS is skipped.
            if copy == 'False':
                print "Copying files for " + GLDS + "..."
                #Process metadata
                metadata_dir = os.path.join(parent_dir,GLDS,'metadata')
                if os.path.isdir(metadata_dir):
                    metadata_process.clean(metadata_dir)
                else:
                    print "metadata directory within " + GLDS + " not found, skipping..."
                    copy, norm_qc = ['Skipped' for j in range(2)]
                    batch_list[i] = [GLDS, copy, norm_qc]

                #Copy rawdata into output and rename files 
                rawdata_dir = os.path.join(parent_dir,GLDS,'microarray')
                if os.path.isdir(rawdata_dir):
                    rawdata_process.copy(rawdata_dir)
                    rawdata_process.rename(os.path.join(config.outdir,GLDS))
                else:
                    print "microarray directory within " + GLDS + " not found, skipping..."
                    copy, norm_qc = ['Skipped' for j in range(2)]
                    batch_list[i] = [GLDS, copy, norm_qc]

                batch_list[i][1] = 'True'
                update_batch(parent_dir,header,batch_file,batch_list)
                print "done"
            elif copy != 'True':
                print "Warning: Files were not copied for " + GLDS + ". If this was not desired, check batch file and make sure this GLDS was set to 'False'."

            #Normalization/QC module, if false perform normalization and QC depending on array type
            if norm_qc == 'False':
                print "Performing QC, normalization, and post-normalization QC on data for " + GLDS + "..."
                rawdata_out = os.path.join(config.outdir,GLDS,'microarray')
                rawdata_process.qc_and_normalize(rawdata_out,GLDS)
                batch_list[i][2] = 'True'
                update_batch(parent_dir,header,batch_file,batch_list)
                print "done"
            elif norm_qc != 'True':
                print "Warning: QC and normalization not performed for " + GLDS + ". If this was not desired, check batch file and make sure this GLDS was set to 'False'."

#This function updates the input batch file based on the batch_list, its meant to be run during batch processing
def update_batch(parent_dir,header,batch_file,batch_list):
    outfile=open(batch_file,'w')
    outfile.write('#Directory='+parent_dir+'\n')
    outfile.write(header)
    for linelist in batch_list:
        outfile.write('\t'.join(linelist)+'\n')
    outfile.close()

==> GeneLab_Microarray-0.4.3-py2-none-any.whl: GeneLab-Microarray/batch_process.py <==
__author__ = 'Jonathan Rubin'

import os, config, metadata_process, rawdata_process

def run(batch_file):
    batch_list = list()
    with open(batch_file) as F:
        parent_dir = F.readline().strip('\n').split('=')[1]
        header = F.readline()
        for line in F:
            linelist = line.strip('\n').split()
            batch_list.append(linelist)


    for i in range(len(batch_list)):
        if 'False' in batch_list[i]:
            GLDS, copy, norm_qc = batch_list[i]

            #Copy module, copies and unzips both metadata and raw data. If precise directories are not found,
            #that GLDS is skipped.
            if copy == 'False':
                print "Copying files for " + GLDS + "..."
                #Process metadata
                metadata_dir = os.path.join(parent_dir,GLDS,'metadata')
                if os.path.isdir(metadata_dir):
                    metadata_process.clean(metadata_dir)
                else:
                    print "metadata directory within " + GLDS + " not found, skipping..."
                    copy, norm_qc = ['Skipped' for j in range(2)]
                    batch_list[i] = [GLDS, copy, norm_qc]

                #Copy rawdata into output
                rawdata_dir = os.path.join(parent_dir,GLDS,'microarray')
                if os.path.isdir(rawdata_dir):
                    rawdata_process.copy(rawdata_dir)
                    rawdata_process.rename(os.path.join(config.outdir,GLDS))
                else:
                    print "microarray directory within " + GLDS + " not found, skipping..."
                    copy, norm_qc = ['Skipped' for j in range(2)]
                    batch_list[i] = [GLDS, copy, norm_qc]

                batch_list[i][1] = 'True'
                update_batch(parent_dir,header,batch_file,batch_list)
                print "done"

            if norm_qc == 'False':
                print "Performing QC, normalization, and post-normalization QC on data for " + GLDS + "..."
                rawdata_out = os.path.join(config.outdir,GLDS,'microarray')
                rawdata_process.qc_and_normalize(rawdata_out,GLDS)
                batch_list[i][2] = 'True'
                update_batch(parent_dir,header,batch_file,batch_list)
                print "done"


def update_batch(parent_dir,header,batch_file,batch_list):
    outfile=open(batch_file,'w')
    outfile.write('#Directory='+parent_dir+'\n')
    outfile.write(header)
    for linelist in batch_list:
        outfile.write('\t'.join(linelist)+'\n')
    outfile.close()
